From 697178524e8e3ff848dbe8be94ea8250d2848f2a Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Thu, 31 Jan 2013 00:16:49 -0600
Subject: Rename KShared

---
 konversation/src/channelnick.cpp         | 2 +-
 konversation/src/channelnick.h           | 6 +++---
 konversation/src/identity.cpp            | 6 +++---
 konversation/src/identity.h              | 4 ++--
 konversation/src/nickinfo.cpp            | 2 +-
 konversation/src/nickinfo.h              | 6 +++---
 konversation/src/server.h                | 2 +-
 konversation/src/servergroupsettings.cpp | 8 ++++----
 konversation/src/servergroupsettings.h   | 4 ++--
 9 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/konversation/src/channelnick.cpp b/konversation/src/channelnick.cpp
index f158550..540dd5a 100644
--- a/konversation/src/channelnick.cpp
+++ b/konversation/src/channelnick.cpp
@@ -25,7 +25,7 @@
 
 ChannelNick::ChannelNick(const NickInfoPtr& nickInfo, const bool& isop, const bool& isadmin,
 			 const bool& isowner, const bool& ishalfop, const bool& hasvoice)
-: KShared()
+: TDEShared()
 {
     this->nickInfo = nickInfo;
     this->isop = isop;
diff --git a/konversation/src/identity.cpp b/konversation/src/identity.cpp
index 30fea93..bcb39db 100644
--- a/konversation/src/identity.cpp
+++ b/konversation/src/identity.cpp
@@ -23,7 +23,7 @@
 
 int Identity::s_availableId = 0;
 
-Identity::Identity() : KShared()
+Identity::Identity() : TDEShared()
 {
     m_id = s_availableId;
     s_availableId++;
@@ -31,7 +31,7 @@ Identity::Identity() : KShared()
     init();
 }
 
-Identity::Identity(int id) : KShared()
+Identity::Identity(int id) : TDEShared()
 {
     if (id < 0)
     {
@@ -46,7 +46,7 @@ Identity::Identity(int id) : KShared()
     init();
 }
 
-Identity::Identity(const Identity& original) : KShared()
+Identity::Identity(const Identity& original) : TDEShared()
 {
     copy(original);
     m_id = original.id();
diff --git a/konversation/src/identity.h b/konversation/src/identity.h
index 7f446c5..7033fcb 100644
--- a/konversation/src/identity.h
+++ b/konversation/src/identity.h
@@ -21,7 +21,7 @@
 
 class TQTextCodec;
 
-class Identity : public KShared
+class Identity : public TDEShared
 {
     public:
         /// Create an Identity with a new id.
@@ -127,7 +127,7 @@ class Identity : public KShared
         void init();
 };
 
-typedef KSharedPtr<Identity> IdentityPtr;
+typedef TDESharedPtr<Identity> IdentityPtr;
 typedef TQValueList<IdentityPtr> IdentityList;
 
 #endif
diff --git a/konversation/src/nickinfo.cpp b/konversation/src/nickinfo.cpp
index efc218e..75d9078 100644
--- a/konversation/src/nickinfo.cpp
+++ b/konversation/src/nickinfo.cpp
@@ -31,7 +31,7 @@
 #include <klocale.h>
 
 
-NickInfo::NickInfo(const TQString& nick, Server* server): KShared()
+NickInfo::NickInfo(const TQString& nick, Server* server): TDEShared()
 {
     m_addressee=Konversation::Addressbook::self()->getKABCAddresseeFromNick(nick, server->getServerName(), server->getDisplayName());
     m_nickname = nick;
diff --git a/konversation/src/server.h b/konversation/src/server.h
index f2aa143..91fc786 100644
--- a/konversation/src/server.h
+++ b/konversation/src/server.h
@@ -213,7 +213,7 @@ void resetNickSelection();
          *  - It is on the notify list and is known to be online.
          *  - The nick initiated a query with the user.
          *
-         * @return A TQMap of KSharedPtrs to NickInfos indexed by lowercase nickname.
+         * @return A TQMap of TDESharedPtrs to NickInfos indexed by lowercase nickname.
          */
         const NickInfoMap* getAllNicks();
         /** Returns the list of members for a channel in the joinedChannels list.
diff --git a/konversation/src/servergroupsettings.cpp b/konversation/src/servergroupsettings.cpp
index 567edfc..643cbb5 100644
--- a/konversation/src/servergroupsettings.cpp
+++ b/konversation/src/servergroupsettings.cpp
@@ -20,7 +20,7 @@ namespace Konversation
     int ServerGroupSettings::s_availableId = 0;
 
     ServerGroupSettings::ServerGroupSettings()
-        : KShared()
+        : TDEShared()
     {
         m_id = s_availableId;
         s_availableId++;
@@ -31,7 +31,7 @@ namespace Konversation
     }
 
     ServerGroupSettings::ServerGroupSettings(int id)
-        : KShared()
+        : TDEShared()
     {
         if(id < 0)
         {
@@ -50,7 +50,7 @@ namespace Konversation
     }
 
     ServerGroupSettings::ServerGroupSettings(const ServerGroupSettings& settings)
-        : KShared()
+        : TDEShared()
     {
         setName(settings.name());
         setServerList(settings.serverList());
@@ -64,7 +64,7 @@ namespace Konversation
     }
 
     ServerGroupSettings::ServerGroupSettings(const TQString& name)
-        : KShared()
+        : TDEShared()
     {
         setName(name);
         m_id = s_availableId;
diff --git a/konversation/src/servergroupsettings.h b/konversation/src/servergroupsettings.h
index 3a7cc2d..0603b8c 100644
--- a/konversation/src/servergroupsettings.h
+++ b/konversation/src/servergroupsettings.h
@@ -54,12 +54,12 @@ namespace Konversation
     };
 
     class ServerGroupSettings;
-    typedef KSharedPtr<ServerGroupSettings> ServerGroupSettingsPtr;
+    typedef TDESharedPtr<ServerGroupSettings> ServerGroupSettingsPtr;
     typedef TQValueList<ServerGroupSettingsPtr> ServerGroupList;
     typedef TQValueList<ServerSettings> ServerList;
     typedef TQValueList<ChannelSettings> ChannelList;
 
-    class ServerGroupSettings : public KShared
+    class ServerGroupSettings : public TDEShared
     {
         public:
             ServerGroupSettings();
diff --git a/konversation/src/channelnick.h b/konversation/src/channelnick.h
index 9587a65..92fd92f 100644
--- a/konversation/src/channelnick.h
+++ b/konversation/src/channelnick.h
@@ -20,7 +20,7 @@
 #include <ksharedptr.h>
 
 
-class ChannelNick :  public TQObject, public KShared
+class ChannelNick :  public TQObject, public TDEShared
 {
     Q_OBJECT
   
@@ -77,10 +77,10 @@ class ChannelNick :  public TQObject, public KShared
         void lessActive();
 };
 
 /** A ChannelNickPtr is a pointer to a ChannelNick.  Since it is a KSharedPtr,
  *  the ChannelNick object is automatically destroyed when all references are destroyed.
  */
-typedef KSharedPtr<ChannelNick> ChannelNickPtr;
+typedef TDESharedPtr<ChannelNick> ChannelNickPtr;
 
 /** A ChannelNickMap is a list of ChannelNick pointers, indexed and sorted by
  *  lowercase nickname.
@@ -77,10 +77,10 @@ class ChannelNick :  public TQObject, public KShared
 };
 
-/** A ChannelNickPtr is a pointer to a ChannelNick.  Since it is a KSharedPtr,
+/** A ChannelNickPtr is a pointer to a ChannelNick.  Since it is a TDESharedPtr,
  *  the ChannelNick object is automatically destroyed when all references are destroyed.
  */
diff --git a/konversation/src/nickinfo.h b/konversation/src/nickinfo.h
index 29bf006..9167b6f 100644
--- a/konversation/src/nickinfo.h
+++ b/konversation/src/nickinfo.h
@@ -33,7 +33,7 @@ class TQTimer;
   Offline (but watched or in addressbook) nicks are stored in the Server object.
 
 */
-class NickInfo : public TQObject, public KShared
+class NickInfo : public TQObject, public TDEShared
 {
     Q_OBJECT
   
@@ -174,10 +174,10 @@ class NickInfo : public TQObject, public KShared
         void nickInfoChanged(void);
 };
 
 /** A NickInfoPtr is a pointer to a NickInfo object.  Since it is a KSharedPtr, the NickInfo
  * object is automatically destroyed when all references are destroyed.
  */
-typedef KSharedPtr<NickInfo> NickInfoPtr;
+typedef TDESharedPtr<NickInfo> NickInfoPtr;
 /** A NickInfoMap is a list of NickInfo objects, indexed and sorted by lowercase nickname.
  */
 typedef TQMap<TQString,NickInfoPtr> NickInfoMap;
@@ -174,10 +174,10 @@ class NickInfo : public TQObject, public KShared
 };
 
-/** A NickInfoPtr is a pointer to a NickInfo object.  Since it is a KSharedPtr, the NickInfo
+/** A NickInfoPtr is a pointer to a NickInfo object.  Since it is a TDESharedPtr, the NickInfo
  * object is automatically destroyed when all references are destroyed.
  */
-- 
cgit v1.2.3

